Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(7366)

Unified Diff: content/public/test/test_utils.cc

Issue 2784493003: Consolidate JNI registrations for mojo system. (Closed)
Patch Set: Rebase only Created 3 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « content/public/test/content_test_suite_base.cc ('k') | content/test/BUILD.gn » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: content/public/test/test_utils.cc
diff --git a/content/public/test/test_utils.cc b/content/public/test/test_utils.cc
index 4afe2321e9f3f4c021831dc3857db3582e9991a7..1f53ee1828c283491400ed821819a46832702399 100644
--- a/content/public/test/test_utils.cc
+++ b/content/public/test/test_utils.cc
@@ -33,6 +33,7 @@
#if defined(OS_ANDROID)
#include "content/browser/android/browser_jni_registrar.h"
+#include "mojo/android/system/mojo_jni_registrar.h"
#endif
namespace content {
@@ -202,9 +203,11 @@ void ResetSchemesAndOriginsWhitelist() {
}
#if defined(OS_ANDROID)
// Registers content/browser JNI bindings necessary for some types of tests.
bool RegisterJniForTesting(JNIEnv* env) {
- return content::android::RegisterBrowserJni(env);
+ return mojo::android::RegisterSystemJni(env) &&
+ content::android::RegisterBrowserJni(env);
}
#endif
« no previous file with comments | « content/public/test/content_test_suite_base.cc ('k') | content/test/BUILD.gn » ('j') | no next file with comments »
@@ -202,9 +203,11 @@ void ResetSchemesAndOriginsWhitelist() {
}
#if defined(OS_ANDROID)
-// Registers content/browser JNI bindings necessary for some types of tests.
+// Registers content/browser and mojo JNI bindings necessary for some types of
+// tests.
bool RegisterJniForTesting(JNIEnv* env) {

Powered by Google App Engine
This is Rietveld 408576698